@@ -49,8 +49,8 @@ class BLUEDEVIL_EXPORT Adapter
     Q_OBJECT
 
     Q_PROPERTY(QString address READ address)
-    Q_PROPERTY(QString name READ name WRITE setName)
-    Q_PROPERTY(QString systemName READ systemName)
+    Q_PROPERTY(QString name READ name)
+    Q_PROPERTY(QString alias READ alias WRITE setAlias)
     Q_PROPERTY(quint32 adapterClass READ adapterClass)
     Q_PROPERTY(bool powered READ isPowered WRITE setPowered)
     Q_PROPERTY(bool discoverable READ isDiscoverable WRITE setDiscoverable)
@@ -75,19 +75,14 @@ public:
     QString address() const;
 
     /**
-     * Returns the friendly name of the adapter.
-     *
-     * Friendly name is alias of the adapter. If no alias is set, it returns
-     * the system name.
-     *
      * @return The friendly name of the adapter.
      */
     QString name() const;
 
     /**
-     * @return The system name (hostname) of the adapter.
+     * @return The alias of the adapter
      */
-    QString systemName() const;
+    QString alias() const;
 
     /**
      * @return The class of the adapter.
@@ -152,9 +147,9 @@ public:
 
 public Q_SLOTS:
     /**
-     *  Set the name (alias) of the adapter
+     *  Set the alias of the adapter
      */
-    void setName(const QString &name);
+    void setAlias(const QString &alias);
 
     /**
      * Sets whether this adapter is consuming energy or not.
